Number Input
============

The Number input is a text input box that is limited to numeric input.

Usage
-----

.. code-block:: Python

    import toga
    
    textbox = toga.NumberInput(min_value=1, max_value=10)

Supported Platforms
-------------------

.. include:: ../supported_platforms/NumberInput.rst

Reference
---------

.. autoclass:: toga.interface.widgets.numberinput.NumberInput
   :members:
   :undoc-members:
   :inherited-members: